getTaskRscriptTemplate: Get the path to the R script task template.

View source: R/taskGlobals.R

getTaskRscriptTemplateR Documentation

Get the path to the R script task template.

Description

Get the path to the R script task template.

Usage

getTaskRscriptTemplate(quiet = FALSE)

Arguments

quiet

suppress error messages, default=FALSE.

Value

The path to the R script task template.


D4TAlink.light documentation built on July 21, 2026, 5:07 p.m.