Restore R data.frame from Apache Arrow feather file.
readFeather(task, type, subdir = NULL, dirCreate = FALSE, quiet = FALSE)Object stored in Apache Arrow feather file, or NULL if file does not exist.
Object of class D4TAlinkTask, as created by initTask.
Filename type. If the type is an array, the cocatenation of the elements is used with separator"-". Filenames have the form [task name]_[type].[ext]
(optional) Subdirectory.
Logical, if TRUE (by default) the directory is created.
issue warning if file does not exists.