setTaskRscriptTemplate: Set the path to the R script task template.

View source: R/taskGlobals.R

setTaskRscriptTemplateR Documentation

Set the path to the R script task template.

Description

Set the path to the R script task template.

Usage

setTaskRscriptTemplate(file)

Arguments

file

path to the Rmd task template.

Value

The path to the Rmd task template invisibly.


D4TAlink.light documentation built on July 21, 2026, 5:07 p.m.